
## CATO-CLI - mutation.policy.wanFirewall.updateSection:
[Click here](https://api.catonetworks.com/documentation/#mutation-updateSection) for documentation on this operation.

### Usage for mutation.policy.wanFirewall.updateSection:

`catocli mutation policy wanFirewall updateSection -h`

`catocli mutation policy wanFirewall updateSection <json>`

`catocli mutation policy wanFirewall updateSection "$(cat < updateSection.json)"`

`catocli mutation policy wanFirewall updateSection '{"policyUpdateSectionInput": {"id": {"id": "ID"}, "policyUpdateSectionInfoInput": {"name": {"name": "String"}}}, "wanFirewallPolicyMutationInput": {"policyMutationRevisionInput": {"id": {"id": "ID"}}}}'`

#### Operation Arguments for mutation.policy.wanFirewall.updateSection ####
`accountId` [ID] - (required) N/A 
`policyUpdateSectionInput` [PolicyUpdateSectionInput] - (required) N/A 
`wanFirewallPolicyMutationInput` [WanFirewallPolicyMutationInput] - (optional) N/A 
